#
# Copyright 2021-2022 Budapest Quantum Computing Group
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import numpy as np

from typing import Callable, Tuple


PermanentFunction = Callable[[np.ndarray, Tuple[int, ...], Tuple[int, ...]], float]
HafnianFunction = Callable[[np.ndarray, Tuple[int, ...]], float]
LoopHafnianFunction = Callable[[np.ndarray, np.ndarray, Tuple[int, ...]], float]
